@@ -8,7 +8,7 @@ use ExtUtils::MakeMaker;
 use XS::Install::Util;
 use XS::Install::Payload;
 
-our $VERSION = '1.2.1';
+our $VERSION = '1.2.3';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile not_available/;
@@ -95,6 +95,10 @@ sub pre_process {
         $params->{CC} = $comp;
     }
     
+    if (my $opt = $ENV{OPTIMIZE}) {
+        $params->{OPTIMIZE} = $opt;
+    }
+    
     canonize_array_split($params->{TYPEMAPS});
     canonize_array_split($params->{PARSE_XS});
     
@@ -461,6 +465,7 @@ sub process_CCFLAGS {
     my $params = shift;
     _string_merge($params->{CCFLAGS}, '-o $@');
     $params->{CCFLAGS} = "$Config{ccflags} $params->{CCFLAGS}" if $params->{CCFLAGS};
+    _string_merge($params->{CCFLAGS}, '-Wno-unused-parameter') if $win32; # on Strawberry's mingw PERL_UNUSED_DECL doesn't work
 }
 
 sub process_LD {
@@ -508,7 +513,7 @@ sub process_test {
         XSOPT     => string_merge($params->{XSOPT}, $tp->{XSOPT}),
         LIBS      => $params->{LIBS},
         MAKEFILE  => 'Makefile.test',
-        OPTIMIZE  => merge_optimize($params->{OPTIMIZE}, "-O0", $tp->{OPTIMIZE}),
+        OPTIMIZE  => merge_optimize($params->{OPTIMIZE}, "-O0", $tp->{OPTIMIZE}, $ENV{TEST_OPTIMIZE}),
         PARSE_XS  => $tp->{PARSE_XS} || $params->{PARSE_XS},
         XS        => {},
         NO_MYMETA => 1,
