@@ -45,7 +45,7 @@ EOF
         DynaLoader::bootstrap_inherit($module, $version);
         1;        
     };
-    DynaLoader::croak($@) if !$ok and !($noboot and $@ and $@ =~ /Can't find 'boot_/i);
+    die($@) if !$ok and !($noboot and $@ and $@ =~ /Can't find 'boot_/i);
     
     if ($flags) {
         no strict 'refs';
@@ -58,4 +58,4 @@ sub load_noboot { load($_[0], $_[1], $_[2], 1) }
 
 *bootstrap = *load;
 
-1;
\ No newline at end of file
+1;
